﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;
using Infragistics.Windows.DataPresenter;

namespace ChangingCellLevelStyles
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>

    public partial class ModelCompareWindow : Window
    {
        #region Fields

        private XmlDocument _xmlDocument = new XmlDocument();
        private XmlDataProvider _xmlDocumentDataProvider;

        #endregion //Fields

        #region Create

        public ModelCompareWindow()
        {
            InitializeComponent();            
            DataContext = this;            
            _xmlDocument.Load("ModelCompare.xml");
        }

        #endregion //Create

        #region Public Interface

        public XmlDataProvider XML
        {
            get
            {
                if (_xmlDocumentDataProvider == null)
                {
                    _xmlDocumentDataProvider = new XmlDataProvider();
                    _xmlDocumentDataProvider.IsAsynchronous = false;
                    _xmlDocumentDataProvider.Document = _xmlDocument;
                    _xmlDocumentDataProvider.XPath = "/Root";
                    _xmlDocumentDataProvider.InitialLoad();
                    _xmlDocumentDataProvider.Refresh();
                }
                return _xmlDocumentDataProvider;
            }
        }

        #endregion //Public Interface

        #region Supporting Methods
        
        private void CompareGrid_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            MarkLabelColumn();
        }

        private void CompareGrid_Loaded(object sender, RoutedEventArgs e)
        {
            MarkDifferences();
        }

        private void CompareGrid_RecordActivating(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatingEventArgs e)
        {
            e.Cancel = true;
        }

        private void MarkLabelColumn()
        {
            foreach (Field f in this.CompareGrid.DefaultFieldLayout.Fields)
            {
                if (f == this.CompareGrid.DefaultFieldLayout.Fields[0])
                {
                    f.Width = FieldLength.InitialAuto;
                    f.Settings.CellValuePresenterStyle = (Style)this.Resources["PropertyNameStyle"];
                }
                else
                {
                    f.Width = new FieldLength(1, FieldLengthUnitType.Star);
                }
            }
        }

        private void MarkDifferences()
        {
            foreach (DataRecord r in this.CompareGrid.Records)
            {
                Cell c = null;
                Cell anchor = null;
                for (int i = 1; i < r.Cells.Count; i++)
                {
                    if (i == 1)
                    {
                        anchor = r.Cells[i];
                        r.FieldLayout.Fields[i].Settings.CellValuePresenterStyle = (Style)this.Resources["DefaultPropertyDataStyle"];
                        continue;
                    }
                    else
                    {
                        c = r.Cells[i];
                    }
                    if ((anchor != null) && (i >= 2))
                    {                        
                        if (!anchor.Value.Equals(c.Value))
                        {
                            //cvp is always null not sure why yet
                            //CellValuePresenter cvp = CellValuePresenter.FromCell(c);
                            //if (cvp != null)
                            //{
                            //    //cvp.Foreground = Brushes.Red;
                            //    cvp.Style = (Style)this.Resources["DifferencePropertyDataStyle"];
                            //}                            
                            
                            //Turns everything red for the whole column instead of just the cell
                            c.Field.Settings.CellValuePresenterStyle = (Style)this.Resources["DifferentPropertyDataStyle"];
                        }
                    }
                }
            }
        }
        
        #endregion //Supporting Methods

    }
}

